searchData={"items":[{"type":"module","title":"IntelHex","doc":"Manipulate Intel HEX files\n\nThis is the main interface for loading, modifying and saving Intel HEX files.\nIn general, you'll want to use methods here for most operations.\n\nInternally, data is stored as lists of `IntelHex.Block` structs. See that\nmodule for transformations that aren't possible with the main functions.","ref":"IntelHex.html"},{"type":"function","title":"IntelHex.crop/3","doc":"Only keep data within the specified address range","ref":"IntelHex.html#crop/3"},{"type":"function","title":"IntelHex.get/4","doc":"Get the data at a specified address\n\nOptions:\n* `:fill` - value to use when none exists (defaults to `0`)","ref":"IntelHex.html#get/4"},{"type":"function","title":"IntelHex.load/1","doc":"Load an Intel Hex-formatted file into memory","ref":"IntelHex.html#load/1"},{"type":"function","title":"IntelHex.load!/1","doc":"Load an Intel Hex-formatted file into memory\n\nRaises File.Error or IntelHex.DecodeError if an error occurs.","ref":"IntelHex.html#load!/1"},{"type":"function","title":"IntelHex.new/0","doc":"Create an empty hex file\n\nUse `IntelHex.set/3` or other functions to populate it.","ref":"IntelHex.html#new/0"},{"type":"function","title":"IntelHex.save/3","doc":"Save data to an Intel Hex-formatted file\n\nOptions:\n* `:block_size` - the max data bytes per record. (defaults to 16)","ref":"IntelHex.html#save/3"},{"type":"function","title":"IntelHex.set/3","doc":"Set a set of bytes at the specified address","ref":"IntelHex.html#set/3"},{"type":"type","title":"IntelHex.t/0","doc":"Primary type for handling Intel Hex file data","ref":"IntelHex.html#t:t/0"},{"type":"module","title":"IntelHex.Block","doc":"A block is a contiguous set of bytes at an address\n\nIf you're working with `IntelHex` only, then you don't need to worry about\nthis module. However, handling blocks directly can enable more complex\nmanipulations of the data stored in `.hex` files.\n\nGenerally programs pass around lists of `Block`s. Functions in this library\nexpect these lists to conform to the following rules:\n\n1. Sorted by address from lowest address to highest\n2. No overlaps between blocks\n3. A gap of one or more bytes separates each block\n\nCalling `normalize/1` will ensure that `Block` lists follow these rules.","ref":"IntelHex.Block.html"},{"type":"function","title":"IntelHex.Block.blocks_to_records/2","doc":"Turn a list of memory blocks back to records\n\nOnly linear addressing is supported.\n\nOptions:\n* `:block_size` - the max data bytes per record. (defaults to 16)","ref":"IntelHex.Block.html#blocks_to_records/2"},{"type":"function","title":"IntelHex.Block.new/2","doc":"Create a new block","ref":"IntelHex.Block.html#new/2"},{"type":"function","title":"IntelHex.Block.normalize/1","doc":"Normalize a list of blocks\n\nThis makes sure that they're sorted, non-overlapping and blocks that are next\nto each other get merged. This is normally done automatically, but if you're\nmanually creating block lists and unsure whether there are overlaps or\nadjacent blocks, then it's recommended to run this.","ref":"IntelHex.Block.html#normalize/1"},{"type":"function","title":"IntelHex.Block.records_to_blocks/1","doc":"Convert a list of records to memory blocks\n\nThe returned list of blocks is sorted, merged, and any overlaps resolved.","ref":"IntelHex.Block.html#records_to_blocks/1"},{"type":"type","title":"IntelHex.Block.t/0","doc":"","ref":"IntelHex.Block.html#t:t/0"},{"type":"module","title":"IntelHex.Record","doc":"Information for one line in an Intel HEX file","ref":"IntelHex.Record.html"},{"type":"function","title":"IntelHex.Record.data/2","doc":"Helper for creating data records","ref":"IntelHex.Record.html#data/2"},{"type":"function","title":"IntelHex.Record.decode/1","doc":"Decode one Intel Hex record","ref":"IntelHex.Record.html#decode/1"},{"type":"function","title":"IntelHex.Record.decode!/1","doc":"Decode one Intel Hex record\n\nIf the record is not in Intel Hex format, an exception will be raised.","ref":"IntelHex.Record.html#decode!/1"},{"type":"function","title":"IntelHex.Record.encode/1","doc":"Encode an Intel Hex record","ref":"IntelHex.Record.html#encode/1"},{"type":"function","title":"IntelHex.Record.eof/0","doc":"Helper for creating an EOF record","ref":"IntelHex.Record.html#eof/0"},{"type":"function","title":"IntelHex.Record.extended_linear_address/1","doc":"Helper for creating an extended linear address record","ref":"IntelHex.Record.html#extended_linear_address/1"},{"type":"type","title":"IntelHex.Record.t/0","doc":"","ref":"IntelHex.Record.html#t:t/0"},{"type":"type","title":"IntelHex.Record.type/0","doc":"","ref":"IntelHex.Record.html#t:type/0"},{"type":"exception","title":"IntelHex.DecodeError","doc":"","ref":"IntelHex.DecodeError.html"},{"type":"extras","title":"IntelHex","doc":"# IntelHex\n\n[![CircleCI](https://circleci.com/gh/fhunleth/intel_hex.svg?style=svg)](https://circleci.com/gh/fhunleth/intel_hex)\n[![Hex version](https://img.shields.io/hexpm/v/intel_hex.svg \"Hex version\")](https://hex.pm/packages/intel_hex)\n\nThis is a library for loading, modifying and saving [Intel HEX\nfiles](https://en.wikipedia.org/wiki/Intel_HEX). This file format is frequently\nused for firmware images on microcontrollers.\n\nHere's an example use:\n\n```elixir\niex> hex = IntelHex.load!(\"./test/test.hex\")\n%IntelHex{}\n\n# Take a look at the first two 16-bit integers\niex>  > = IntelHex.get(hex, 0, 4); {x, y}\n{6146, 512}\n\n# Change them to {1, 2}\niex> hex = IntelHex.set(hex, 0,  >)\n%IntelHex{}\n\n# Check that it worked.\niex>  > = IntelHex.get(hex, 0, 4); {x,y}\n{1, 2}\n\n# Save it to a new file\niex> IntelHex.save(hex, \"new.hex\")\n:ok\n```","ref":"readme.html"},{"type":"extras","title":"Installation - IntelHex","doc":"The package can be installed by adding `intel_hex` to your list of dependencies\nin `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:intel_hex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"This is almost a complete rewrite to support creating, modifying and saving\nIntel Hex files. All APIs changed to focus on manipulating data in contiguous\nblocks rather than records.","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release to hex.","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown"}